local ship = {
	x = 0,
	y = 0,
	velocity = {
		x = 0,
		y = 0,
	},
	stats = {
		speed = 1000,
	},
	trail = {
	},
	dampeners = false,
}

function ship:update(dt)
	if love.mouse.isDown("r") then
		local ax,ay = cam.toRealCoords(love.mouse.getX(),love.mouse.getY())
		local rx=ax-self.x
		local ry=ay-self.y
		local angle=math.atan2(rx,ry)
		local distance=math.sqrt(math.abs(rx^2)+math.abs(ry^2))
		local vx=math.sin(angle)*self.stats.speed*dt
		local vy=math.cos(angle)*self.stats.speed*dt
		
		self:addForce(vx,vy)
	elseif self.dampeners then
		local angle=math.atan2(self.velocity.x,self.velocity.y)
		local vx=math.sin(angle)*dt*self.stats.speed
		local vy=math.cos(angle)*dt*self.stats.speed
		
		self:addForce(-vx,-vy)
	end
	
	for k,object in pairs(world.objects) do
		if object.type == "planet" then
			local rx=object.x-ship.x
			local ry=object.y-ship.y
			local srx=math.abs(rx)-object.size
			local sry=math.abs(ry)-object.size
			if srx < object.mass*2 and sry < object.mass*2 then
				local angle=math.atan2(rx,ry)
				local vx=(math.sin(angle))*object.mass*dt
				local vy=(math.cos(angle))*object.mass*dt
				ship:addForce(vx,vy)
			end
		end
	end
	
	table.insert(ship.trail,1,{x=ship.x,y=ship.y})
	ship.trail[maxtraillength+1] = nil
	
	ship.x=ship.x+(ship.velocity.x*dt)
	ship.y=ship.y+(ship.velocity.y*dt)
end

function ship:draw()
	love.graphics.setLineWidth(4)
	love.graphics.setBlendMode("alpha")
	love.graphics.setLineStyle("smooth")
	local traildraw = {}
	for p=0,traillength do
		local p1 = self.trail[p] or {x=self.x,y=self.y}
		table.insert(traildraw,1,p1.y)
		table.insert(traildraw,1,p1.x)
	end
	love.graphics.setColor(255,127,0,255)
	love.graphics.line(traildraw)
	love.graphics.setBlendMode("alpha")
	love.graphics.setLineWidth(1/cam.s)
	love.graphics.setColor(255,255,255,255)
	love.graphics.setLineStyle("rough")
	love.graphics.line(self.x,self.y,self.x+self.velocity.x,self.y+self.velocity.y)
	love.graphics.draw(graphics.ship,self.x,self.y,math.atan2(self.velocity.x,-self.velocity.y),0.25,0.25,graphics.ship:getWidth()/2,graphics.ship:getHeight()/2)
end

function ship:addForce(vx,vy)
	self.velocity.x=self.velocity.x+vx
	self.velocity.y=self.velocity.y+vy
end

return ship