local mainmenu = {}

function mainmenu:load()
	self.options = {
		"Start game",
		--"Options",
		"Toggle fullscreen",
		"Exit"
	}
	self.spacing = 32
	mainmenu:readjust()
end

function mainmenu:readjust()
	self.width = 0
	for option,name in pairs(self.options) do
		local c = fonts.regular:getWidth(name)+32
		if c > self.width then
			self.width = c
		end
	end
end
	

function mainmenu:draw()
	local topy = screen.height-((32+self.spacing)*#self.options)
	
	for option,name in pairs(self.options) do
		local x = (screen.width-self.width)/2
		local y = topy+((option-1)*(32+self.spacing))
		local drawtype="line"
		local second={255,255,255,255}
		love.graphics.setFont(fonts.regular)
		if rgul.inside(love.mouse.getX(),x,x+self.width) and rgul.inside(love.mouse.getY(),y,y+32)  then
			drawtype="fill"
			second={0,0,0,255}
		end
		love.graphics.setColor(255,255,255,255)
		love.graphics.rectangle(drawtype,x,y,self.width,32)
		love.graphics.setColor(second)
		love.graphics.print(name,x+(self.width-fonts.regular:getWidth(name))/2,y+(fonts.regular:getBaseline()/2))
		love.graphics.setBlendMode("alpha")
	end
end
function mainmenu:mousepressed(x,y,b)
	local topy = screen.height-((32+self.spacing)*#self.options)
	for option,name in pairs(self.options) do
		local bx = (screen.width-self.width)/2
		local by = topy+((option-1)*(32+self.spacing))
		if rgul.inside(x,bx,bx+self.width) and rgul.inside(y,by,by+32) then
			local fullstring = "Fullscreen"
			if love.window.getFullscreen() then
				fullstring = "Windowed"
			end
			if name == "Start game" then
				rstate.load(require("states/game"))
			elseif name == "Options" then
				self:menu_options()
			elseif name == "Exit" then
				love.event.quit()
			elseif name == "Screen resolution" then
				local modes = love.window.getFullscreenModes()
				self.options = {}
				self.spacing = 0
				--table.sort(modes)
				for k,v in ipairs(modes) do
					if v.height >= 480 then
						table.insert(self.options,v.width .. "x" .. v.height)
					end
				end
			elseif name == fullstring or name == "Toggle fullscreen" then
				love.window.setFullscreen(not love.window.getFullscreen())
				--screen.init(nil,nil)
			elseif name == "Back" then
				if self.options[1] == "Screen resolution" then
					mainmenu:load()
				end
			elseif name:match("%d+x%d+") then
				screen.init(tonumber(name:match("^%d+")),tonumber(name:match("%d+$")))
				self:menu_options()
			else
				print(name)
			end
		end
	end
end

function mainmenu:menu_options()
	local fullstring = "Fullscreen"
	if love.window.getFullscreen() then
		fullstring = "Windowed"
	end
	self.options = {
		"Screen resolution",
		fullstring,
		"Back"
	}
	mainmenu:readjust()
end

return mainmenu





--[[

000 __128
xxx __160
xxx __192
xxx __224
000 __256

]]